
/* Generated data (by glib-mkenums) */

#ifndef __LIBXFCE4UI_ENUM_TYPES_H__
#define __LIBXFCE4UI_ENUM_TYPES_H__

G_BEGIN_DECLS

/* enumerations from "xfce-sm-client.h" */

GType xfce_sm_client_restart_style_get_type(void) G_GNUC_CONST;
#define XFCE_TYPE_SM_CLIENT_RESTART_STYLE (xfce_sm_client_restart_style_get_type())

GType xfce_sm_client_shutdown_hint_get_type(void) G_GNUC_CONST;
#define XFCE_TYPE_SM_CLIENT_SHUTDOWN_HINT (xfce_sm_client_shutdown_hint_get_type())

G_END_DECLS

#endif /* !__LIBXFCE4UI_ENUM_TYPES_H__ */

/* Generated data ends here */

